Compatibility Functions for ICalendar
=====================================

.. image:: https://badge.fury.io/py/icalendar_compatibility.svg
   :target: https://pypi.org/project/icalendar_compatibility/
   :alt: Python Package Version on PyPI

.. image:: https://img.shields.io/pypi/pyversions/icalendar_compatibility
   :target: https://pypi.org/project/icalendar_compatibility/
   :alt: PyPI - Python Version

.. image:: https://img.shields.io/pypi/dm/icalendar-compatibility.svg
   :target: https://pypi.org/project/icalendar-compatibility/#files
   :alt: Downloads from PyPI

.. image:: https://img.shields.io/github/actions/workflow/status/niccokunzmann/icalendar_compatibility/tests.yml?branch=main&label=main&logo=github
    :target: https://github.com/niccokunzmann/icalendar_compatibility/actions/workflows/tests.yml?query=branch%3Amain
    :alt: GitHub Actions build status for main

.. image:: https://readthedocs.org/projects/icalendar-compatibility/badge/?version=latest
    :target: https://icalendar-compatibility.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

**Simple access to icalendar event information with maximum compatibility.**

ICS files - altough specified by `RFC 5545`_ - differ widely in how to specify event information.
This packages provides a unified interface.

.. _`RFC 5545`: https://www.rfc-editor.org/rfc/rfc5545.html
.. _`icalendar`: https://pypi.org/project/icalendar/


Links:

- `documentation`_
- `source code`_
- `change log`_

Contributing
------------

This packages is open-sources so you can use it and improve it for the calendars you use.
If the calendar does not yield the right information, please `open an issue <https://github.com/niccokunzmann/icalendar_compatibility/issues>`_!

Installation
------------

To install the package from `PyPI`_, run::

    pip install icalendar_compatibility


.. _`PyPI`: https://pypi.org/project/icalendar-compatibility

Documentation
-------------

Please have a look at the `documentation`_.

Related Work
------------

- Used by the `Open Web Calendar <https://open-web-calendar.quelltext.eu/>`_
- This package is based on `icalendar`_.

.. _`documentation`: https://icalendar-compatibility.readthedocs.io
.. _`source code`: https://github.com/niccokunzmann/icalendar_compatibility
.. _`change log`: https://icalendar-compatibility.readthedocs.io/en/latest/changes.html

License
-------

This work is licensed under GPL version 2 or any later version e.g. GPLv3.

